@@ -5,12 +5,12 @@ module Gitlab
     module Variables
       class Collection
         class Item
-          def initialize(key:, value:, public: true, file: false)
+          def initialize(key:, value:, public: true, file: false, masked: false)
             raise ArgumentError, "`#{key}` must be of type String or nil value, while it was: #{value.class}" unless
               value.is_a?(String) || value.nil?
 
             @variable = {
-              key: key, value: value, public: public, file: file
+              key: key, value: value, public: public, file: file, masked: masked
             }
           end
 
@@ -27,9 +27,13 @@ module Gitlab
           # don't expose `file` attribute at all (stems from what the runner
           # expects).
           #
+          # If the `variable_masking` feature is enabled we expose the `masked`
+          # attribute, otherwise it's not exposed.
+          #
           def to_runner_variable
             @variable.reject do |hash_key, hash_value|
-              hash_key == :file && hash_value == false
+              (hash_key == :file && hash_value == false) ||
+                (hash_key == :masked && !Feature.enabled?(:variable_masking))
             end
           end
 
